@@ -57,7 +57,8 @@
 ;; ================
 ;; Ada, Assembly, BibTex, C++, C, Dired, Ehdm, ELisp, FORTRAN, Ksh, Latex,
 ;; Lelisp, Makefile, Maple, Modula2, Modula3, Outline, Objective-C, Pascal,
-;; Perl, Postscript, Prolog, PVS, Python, SGML, Scheme, Tcl, Verilog, Manual
+;; Perl, Postscript, Prolog, PVS, Python, SGML, Scheme, Tcl, Verilog,
+;; Manual, Ruby
 ;;
 ;; Acknowledgements:
 ;; =================
@@ -146,6 +147,10 @@
 ;; Alex Rezinsky <alexr@msil.sps.mot.com>
 ;; Michael Lamoureux <lamour@engin.umich.edu>
 ;;
+;; Ruby Support
+;; Stefan Kamphausen <mail@skamphausen.de>
+;; Albert Davidson Chou <Al_Chou@CyberDude.com>
+;;
 ;; Suggested mouse interface
 ;; Raymond L. Toy <toy@soho.crd.ge.com>
 ;;
@@ -782,6 +787,12 @@ displayed in the modeline.")
 (defvar fume-function-name-regexp-perl "^sub[ \t]+\\([A-Za-z0-9_]+\\)"
   "Expression to get Perl function Names")
 
+;;; Ruby
+;;; Stefan Kamphausen <mail@skamphausen.de>
+;;; Albert Davidson Chou <Al_Chou@CyberDude.com>
+(defvar fume-function-name-regexp-ruby
+  "^\\s *\\(?:class\\|def\\)+\\s *\\([^(\n ]+\\)")
+
 ;;; Python support
 ;;; Shuichi Koga <skoga@virginia.edu>
 ;;;
@@ -1022,6 +1033,9 @@ can be very slow for large or non-trivial Makefiles.
     ;; Perl
     (perl-mode . fume-function-name-regexp-perl)
 
+	;; Ruby
+    (ruby-mode . fume-function-name-regexp-ruby)
+
     ;; Java
     (java-mode . fume-function-name-regexp-java)
     (jde-mode  . fume-function-name-regexp-java)
@@ -1277,6 +1291,15 @@ can be very slow for large or non-trivial Makefiles.
   "Searches for the next Perl function in BUFFER."
   (fume-find-next-sexp buffer))
 
+;;; Specialised routine to find the next Ruby function
+;;; FIXME: this should be more like the python function:
+;;; concatenating the class's name with the method's name, but
+;;; my lisp is not good enough for that.
+;;;
+(defun fume-find-next-ruby-function-name (buffer)
+  "Searches for the next ruby function in BUFFER."
+  (fume-find-next-sexp buffer))
+
 ;;; Specialised routine to find the next Java function
 ;;; Bob Weiner <weiner@altrasoft.com>
 ;;; Heddy Boubaker <boubaker@dgac.fr>
@@ -1616,6 +1639,7 @@ can be very slow for large or non-trivial Makefiles.
     (modula-3-mode   . fume-find-next-modula-function-name)
     (pascal-mode     . fume-find-next-pascal-function-name)
     (perl-mode       . fume-find-next-perl-function-name)
+    (ruby-mode       . fume-find-next-ruby-function-name)
     (java-mode       . fume-find-next-java-function-name)
     (jde-mode        . fume-find-next-java-function-name)
     (postscript-mode . fume-find-next-postscript-function-name)
